ServiceClientDescription class

Constructors

ServiceClientDescription({required String serviceId, required String transportId, required Uri baseUrl, required String redactedSummary})
const

Properties

baseUrl Uri
final
hashCode int
The hash code for this object.
no setterinherited
redactedSummary String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serviceId String
final
transportId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited